@@ -1,7 +1,7 @@
 #define QT_VERSION_MAJOR    5
-#define QT_VERSION_MINOR    6
+#define QT_VERSION_MINOR    7
 #define QT_VERSION_PATCH    1
-#define QT_VERSION_STR      "5.6.1"
+#define QT_VERSION_STR      "5.7.1"
 
 /* Everything */
 /* Compile time features */
@@ -23,30 +23,12 @@
 # define QT_NO_IMAGEFORMAT_JPEG
 #endif
 
-#if defined(QT_NO_LIBPROXY) && defined(QT_LIBPROXY)
-# undef QT_NO_LIBPROXY
-#elif !defined(QT_NO_LIBPROXY) && !defined(QT_LIBPROXY)
-# define QT_NO_LIBPROXY
-#endif
-
 #if defined(QT_NO_OPENVG) && defined(QT_OPENVG)
 # undef QT_NO_OPENVG
 #elif !defined(QT_NO_OPENVG) && !defined(QT_OPENVG)
 # define QT_NO_OPENVG
 #endif
 
-#if defined(QT_NO_TABLET) && defined(QT_TABLET)
-# undef QT_NO_TABLET
-#elif !defined(QT_NO_TABLET) && !defined(QT_TABLET)
-# define QT_NO_TABLET
-#endif
-
-#if defined(QT_NO_XINPUT) && defined(QT_XINPUT)
-# undef QT_NO_XINPUT
-#elif !defined(QT_NO_XINPUT) && !defined(QT_XINPUT)
-# define QT_NO_XINPUT
-#endif
-
 #if defined(QT_NO_ZLIB) && defined(QT_ZLIB)
 # undef QT_NO_ZLIB
 #elif !defined(QT_NO_ZLIB) && !defined(QT_ZLIB)
@@ -71,6 +53,12 @@
 # define QT_OPENGL_ES_3
 #endif
 
+#if defined(QT_OPENGL_ES_3_1) && defined(QT_NO_OPENGL_ES_3_1)
+# undef QT_OPENGL_ES_3_1
+#elif !defined(QT_OPENGL_ES_3_1) && !defined(QT_NO_OPENGL_ES_3_1)
+# define QT_OPENGL_ES_3_1
+#endif
+
 #if defined(QT_RUNTIME_XCURSOR) && defined(QT_NO_RUNTIME_XCURSOR)
 # undef QT_RUNTIME_XCURSOR
 #elif !defined(QT_RUNTIME_XCURSOR) && !defined(QT_NO_RUNTIME_XCURSOR)
@@ -83,12 +71,6 @@
 # define QT_RUNTIME_XFIXES
 #endif
 
-#if defined(QT_RUNTIME_XINERAMA) && defined(QT_NO_RUNTIME_XINERAMA)
-# undef QT_RUNTIME_XINERAMA
-#elif !defined(QT_RUNTIME_XINERAMA) && !defined(QT_NO_RUNTIME_XINERAMA)
-# define QT_RUNTIME_XINERAMA
-#endif
-
 #if defined(QT_RUNTIME_XRANDR) && defined(QT_NO_RUNTIME_XRANDR)
 # undef QT_RUNTIME_XRANDR
 #elif !defined(QT_RUNTIME_XRANDR) && !defined(QT_NO_RUNTIME_XRANDR)
